@@ -15,7 +15,7 @@ import sys
 import shutil
 from datetime import datetime, timedelta
 from pathlib import Path
-from subprocess import call
+from subprocess import run, PIPE, STDOUT
 from typing import Dict, AnyStr
 from urllib.request import urlopen
 from distutils.spawn import find_executable
@@ -28,7 +28,7 @@ except ImportError:
     raise RuntimeError("This module must ONLY run as part of a Colab notebook!")
 
 
-__version__ = "0.1.2"
+__version__ = "0.1.3"
 __author__ = "Jaime Rodríguez-Guerra <jaimergp@users.noreply.github.com>"
 
 
@@ -82,8 +82,19 @@ def install_from_url(
         shutil.copyfileobj(response, out)
 
     print("📦 Installing...")
-    call(["bash", installer_fn, "-bfp", str(prefix)])
+    task = run(
+        ["bash", installer_fn, "-bfp", str(prefix)],
+        check=False,
+        stdout=PIPE,
+        stderr=STDOUT,
+        text=True,
+    )
     os.unlink(installer_fn)
+    with open("condacolab_install.log", "w") as f:
+        f.write(task.stdout)
+    assert (
+        task.returncode == 0
+    ), "💥💔💥 The installation failed! Logs are available at `/content/condacolab_install.log`."
 
     print("📌 Adjusting configuration...")
     cuda_version = ".".join(os.environ.get("CUDA_VERSION", "*.*.*").split(".")[:2])
@@ -116,14 +127,17 @@ def install_from_url(
 
     print("🩹 Patching environment...")
     env = env or {}
-    env["LD_LIBRARY_PATH"] = f'"{prefix}/lib:$LD_LIBRARY_PATH"'
+    bin_path = f"{prefix}/bin"
+    if bin_path not in os.environ.get("PATH", "").split(":"):
+        env["PATH"] = f"{bin_path}:{os.environ.get('PATH', '')}"
+    env["LD_LIBRARY_PATH"] = f"{prefix}/lib:{os.environ.get('LD_LIBRARY_PATH', '')}"
 
     os.rename(sys.executable, f"{sys.executable}.real")
     with open(sys.executable, "w") as f:
         f.write("#!/bin/bash\n")
         envstr = " ".join(f"{k}={v}" for k, v in env.items())
         f.write(f"exec env {envstr} {sys.executable}.real -x $@\n")
-    call(["chmod", "+x", sys.executable])
+    run(["chmod", "+x", sys.executable])
 
     taken = timedelta(seconds=round((datetime.now() - t0).total_seconds(), 0))
     print(f"⏲ Done in {taken}")
@@ -282,6 +296,9 @@ def check(prefix: os.PathLike = PREFIX, verbose: bool = True):
     pymaj, pymin = sys.version_info[:2]
     sitepackages = f"{prefix}/lib/python{pymaj}.{pymin}/site-packages"
     assert sitepackages in sys.path, f"💥💔💥 PYTHONPATH was not patched! Value: {sys.path}"
+    assert (
+        f"{prefix}/bin" in os.environ["PATH"]
+    ), f"💥💔💥 PATH was not patched! Value: {os.environ['PATH']}"
     assert (
         f"{prefix}/lib" in os.environ["LD_LIBRARY_PATH"]
     ), f"💥💔💥 LD_LIBRARY_PATH was not patched! Value: {os.environ['LD_LIBRARY_PATH']}"
